@@ -112,10 +112,13 @@ def version_to_tuple(version: str) -> tuple:
 def test_no_duplicate_classifiers(build: Build, pyproject):
     pyproject_meta = pyproject["tool"]["poetry"]
     wheel_meta = build.wheel.get_meta(version=pyproject_meta["version"])
-    classifiers = sorted(wheel_meta.get_all("Classifier"))
-    unique_classifiers = sorted(set(wheel_meta.get_all("Classifier")))
+    classifiers = wheel_meta.get_all("Classifier")
+    assert classifiers is not None
 
-    assert classifiers == unique_classifiers
+    sorted_classifiers = sorted(classifiers)
+    unique_classifiers = sorted(set(classifiers))
+
+    assert sorted_classifiers == unique_classifiers
 
 
 def test_python_version(build: Build, pyproject):
@@ -130,7 +133,10 @@ def test_python_version(build: Build, pyproject):
 
     min_version_tuple = version_to_tuple(min_version)
 
-    for classifier in wheel_meta.get_all("Classifier"):
+    classifiers = wheel_meta.get_all("Classifier")
+    assert classifiers is not None
+
+    for classifier in classifiers:
         if classifier.startswith("Programming Language :: Python ::"):
             version_tuple = version_to_tuple(classifier.split("::")[-1].strip())
             if len(version_tuple) > 1:
@@ -149,6 +155,7 @@ def test_wheel_no_extra_contents(build: Build, version: str):
     assert package_contents == {
         "__init__.py",
         "blocking_httpserver.py",
+        "hooks.py",
         "httpserver.py",
         "py.typed",
         "pytest_plugin.py",
@@ -183,12 +190,14 @@ def test_sdist_contents(build: Build, version: str):
             "howto.rst",
             "index.rst",
             "Makefile",
+            "patch.py",
             "tutorial.rst",
             "upgrade.rst",
         },
         "pytest_httpserver": {
             "__init__.py",
             "blocking_httpserver.py",
+            "hooks.py",
             "httpserver.py",
             "py.typed",
             "pytest_plugin.py",
@@ -200,8 +209,10 @@ def test_sdist_contents(build: Build, version: str):
             "test_blocking_httpserver.py",
             "test_handler_errors.py",
             "test_headers.py",
+            "test_hooks.py",
             "test_ip_protocols.py",
             "test_json_matcher.py",
+            "test_log_querying.py",
             "test_mixed.py",
             "test_oneshot.py",
             "test_ordered.py",
@@ -212,6 +223,7 @@ def test_sdist_contents(build: Build, version: str):
             "test_querystring.py",
             "test_release.py",
             "test_ssl.py",
+            "test_threaded.py",
             "test_urimatch.py",
             "test_wait.py",
             "test_with_statement.py",
